;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "nix-ts-mode" "20251114.1500"
  "Major mode for Nix expressions, powered by tree-sitter."
  '((emacs "29.1"))
  :url "https://github.com/nix-community/nix-ts-mode"
  :commit "03c77fdbbd22d9b87a654169c26339b28c97d8cd"
  :revdesc "03c77fdbbd22"
  :keywords '("nix" "languages" "tree-sitter")
  :maintainers '(("Remi Gelinas" . "mail@remigelin.as")))
